@@ -14,6 +14,7 @@ class QMenu;
 class QAction;
 class QMaemo5ValueButton;
 class QTextBrowser;
+class QWebView;
 class QLabel;
 
 class MainWindow : public QMainWindow 
@@ -58,7 +59,7 @@ private:
 
     QTextBrowser* _scrollForStatusDataPage;
     QTextBrowser* _tubedata;
-    QTextBrowser* _scrollForRouteDataPage;
+    QWebView* _scrollForRouteDataPage;
     QScrollArea* _scrollForMapPage;
 
     QMainWindow *_mainWindow;
